/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Panic Button.
 *
 * The Initial Developer of the Original Code is 
 * Alex Eng <ateng@users.sourceforge.net>.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * ***** END LICENSE BLOCK ***** */


const CUSTOM_TB_ICON_INDEX = 20;

var gUtils, gStrBundle;
var gToolbarIconListElt, gPanicButtonAction, gEnableFuncKey;
var gToolbarBtnCaption, gRestSessToolbarLayout;
var gResetPrefs = false;



function $(aID) {
  return document.getElementById(aID);
}


function init()
{
  gUtils = new aePanicButtonUtils();
  gStrBundle = $("ae-panicbutton-strings");
  gPanicButtonAction = $("panicbutton-action");
  gEnableFuncKey = $("enable-function-key");
  gToolbarBtnCaption = $("toolbar-button-caption");
  gRestSessToolbarLayout = $("restore-session-toolbar-layout");

  var captionStr = gUtils.getPref("panicbutton.toolbarbutton.label");
  if (captionStr == "") {
    gToolbarBtnCaption.value = gStrBundle.getString("panicbutton.defaultLabel");
  }
  else {
    gToolbarBtnCaption.value = captionStr;
  }

  gPanicButtonAction.selectedIndex = gUtils.getPref("panicbutton.action");
  gRestSessToolbarLayout.selectedIndex = gUtils.getPref("panicbutton.restorebar.layout");
  
  // On Mac OS X, Panic Button shortcut key is Command+F9 - the F9 key is a
  // system function key reserved for Expose
  if (gUtils.getOS() == "Darwin") {
    gEnableFuncKey.label = gStrBundle.getString("macEnableShortcutKey");
  }

  gEnableFuncKey.checked = gUtils.getPref("panicbutton.enable_function_key");

  gToolbarIconListElt = $("toolbar-button-icon");

  var imgURL = gUtils.getPref("panicbutton.toolbarbutton.custom_icon_url");
  if (imgURL) {
    $("custom-listitem").setAttribute("collapsed", "false");
    $("custom-image").src = imgURL;
    gToolbarIconListElt.selectedIndex = gToolbarIconListElt.getRowCount() - 1;
    gToolbarIconListElt.ensureSelectedElementIsVisible();
  }
  else {
    gToolbarIconListElt.selectedIndex = gUtils.getPref("panicbutton.toolbarbutton.icon");
  }

  gToolbarIconListElt.ensureSelectedElementIsVisible();
}


function initCustomizeTab()
{
  // This function is invoked by the onselect event handler of the <tabs>
  // element, which is invoked before the onload event handler for the XUL
  // dialog!
  if (! gPanicButtonAction) {
    return;
  }

  var isPBActionHide = gPanicButtonAction.selectedIndex != gUtils.PANICBUTTON_ACTION_HIDE;
  gRestSessToolbarLayout.setAttribute("disabled", isPBActionHide);
  $("toolbar-layout-label").setAttribute("disabled", isPBActionHide);
}


function showChangedPrefMsg()
{
  gUtils.alertEx(document.title, gStrBundle.getString("prefChangeMsg"));
}


function resetCustomizations()
{
  $("toolbar-button-caption").value = gStrBundle.getString("panicbutton.defaultLabel");
  $("restore-session-toolbar-layout").selectedIndex = 0;      
  var gToolbarIconListElt = $("toolbar-button-icon");
  gToolbarIconListElt.selectedIndex = 0;
  gToolbarIconListElt.ensureSelectedElementIsVisible();

  gResetPrefs = true;
}


function setCustomTBIcon()
{
  var fp = Components.classes['@mozilla.org/filepicker;1']
                     .createInstance(Components.interfaces.nsIFilePicker);
 
  fp.init(window, gStrBundle.getString("customIconDlgTitle"), fp.modeOpen);
  fp.appendFilters(fp.filterImages);

  var rv = fp.show();
  if (rv != fp.returnOK) {
    return;
  }

  var imgURL = fp.fileURL.QueryInterface(Components.interfaces.nsIURI).spec;
  if (! imgURL) {
    gUtils.alertEx(document.title, gStrBundle.getString("errorInvalidCustomIconURL"));
    return;
  }
  
  $("custom-listitem").setAttribute("collapsed", "false");
  $("custom-image").src = imgURL;
  gToolbarIconListElt.selectedIndex = gToolbarIconListElt.getRowCount() - 1;
  gToolbarIconListElt.focus();
}


function doOK()
{
  gUtils.setPref("panicbutton.action", gPanicButtonAction.selectedIndex);
  gUtils.setPref("panicbutton.enable_function_key", gEnableFuncKey.checked);
  gUtils.setPref("panicbutton.toolbarbutton.label", gToolbarBtnCaption.value);
  gUtils.setPref("panicbutton.restorebar.layout", gRestSessToolbarLayout.selectedIndex);

  if (gToolbarIconListElt.selectedIndex == CUSTOM_TB_ICON_INDEX) {
    var imgURL = $("custom-image").src;
    gUtils.log("URL of custom Panic Button toolbar button image:\n" + imgURL);
    gUtils.setPref("panicbutton.toolbarbutton.custom_icon_url", imgURL);
  }
  else {
    gUtils.setPref("panicbutton.toolbarbutton.icon", 
		    gToolbarIconListElt.selectedIndex);
    gUtils.setPref("panicbutton.toolbarbutton.custom_icon_url", "");
  }

  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                     .getService(Components.interfaces.nsIWindowMediator);
  var wndEnum = wm.getEnumerator("navigator:browser");
  while (wndEnum.hasMoreElements()) {
    var wnd = wndEnum.getNext();
    wnd.extensions.aecreations.panicbutton.applyUserPrefs();
  }

  return true;
}

